class XBoxController:
    """
    Mappings for XBox Controller ports
    """
    A = 1
    B = 2
    X = 3
    Y = 4
    LB = 5
    RB = 6
    LT = -2
    RT = -3
    SELECT = 7
    START = 8
    L_JOY = (0, 1)  # (x, y)
    R_JOY = (4, 5)  # (x, y)


class LogitechController:
    """
    Mappings for Logitech Controller ports
    """
    A = 2
    B = 3
    X = 1
    Y = 4
    LB = 5
    RB = 6
    LT = 7
    RT = 8
    SELECT = 9
    START = 10
    L_JOY = (0, 1)  # (x, y)
    R_JOY = (2, 3)  # (x, y)
